# Automated Test Script Command Line Flags

The following command line flags have been added to all test scripts generated by the Desktop Automation Recorder:

## Available Flags

### `-y, --yes`
Automatically answers "yes" to all "Continue anyway?" prompts that appear when visual checks fail. 
This allows the test to continue running even when visual checks don't match the reference screenshots.

### `-n, --no`
Automatically answers "no" to all "Continue anyway?" prompts, causing the test to stop immediately 
when any visual check fails. This is useful for strict validation where any visual difference should 
cause the test to fail.

### `--headless`
Runs the test in headless mode, which automatically continues past any visual check failures without 
showing prompts. Similar to `--yes` but designed for use in automated CI/CD environments.

## Exit Codes

- With `--yes` or `--headless`: The script always exits with code 0 (success), even if checks fail
- With `--no`: The script exits with code 1 (failure) if any check fails
- With both `--yes` and `--no`: The script exits with code 2 (invalid arguments)

## Examples

```
# Run test with automatic continuation on failures
python my_test.py --yes

# Run test with strict checking (stop on first failure)
python my_test.py --no

# Run test in headless/CI mode
python my_test.py --headless
```

## Usage Notes

- The `--yes` flag is useful for development when you want to see all failures in a single run
- The `--no` flag is useful for strict validation where any failure is critical
- The `--headless` flag is intended for automated CI/CD pipelines
- You cannot use both `--yes` and `--no` flags together

When any check fails, detailed information will still be logged to the console and saved in the test report,
regardless of which flag is used. The flags only control whether execution continues and what exit code is returned. 